package com.lyg.application.dao;

import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.read.listener.ReadListener;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;

import java.util.ArrayList;
import java.util.List;

@Slf4j
public class UploadDataListener<T> implements ReadListener<T> {


    private static final int BATCH_COUNT = 10;
    final List<String> errorMessages = new ArrayList<>();
    private final List<T> dataList = new ArrayList<>();
    private final EntityHandler<T> entityHandler;

    public UploadDataListener(EntityHandler<T> entityHandler) {
        this.entityHandler = entityHandler;
    }

    @SneakyThrows
    @Override
    public void invoke(T data, AnalysisContext context) {
        log.info("解析到一条数据: {}", data);
        if (data == null) {
            throw new RuntimeException("excel读取失败");
        }
        Integer index = context.readRowHolder().getRowIndex() + 1;

        T processedData = entityHandler.handleEntity(data, index);
        if (processedData != null) {
            dataList.add(processedData);
            if (dataList.size() >= BATCH_COUNT) {
                saveData();
            }
        }


    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {
        saveData();
        log.info("所有数据解析完成！");
    }
//    public List<String> getErrorMessages() {
//        return errorMessages;
//    }

//    public List<T> getDataList() {
//        return dataList;
//    }

    public void saveData() {
        log.info("正在读取 {} 条数据", dataList.size());
//        log.info("错误信息列表: {}", errorMessages);
        if (!dataList.isEmpty()) { // 只有当数据列表不为空且没有错误信息时才保存数据
            entityHandler.saveEntityBatch(dataList);
            dataList.clear();
        }
    }
}
