package com.lyg.application.service.impl;

import com.lyg.application.dao.EntityHandler;
import com.lyg.application.entity.TaRotation;
import com.lyg.application.mapper.TaRotationMapper;
import com.lyg.application.service.TaRotationService;
import com.lyg.system.service.SysOrgService;
import com.lyg.system.service.SysPositionService;
import com.lyg.system.service.impl.BaseServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;

/**
 * 轮岗列表;(ta_rotation)表服务实现类
 *
 * @author : http://www.chiner.pro
 * @date : 2024-3-6
 */
@Service

public class TaRotationServiceImpl extends BaseServiceImpl<TaRotationMapper, TaRotation> implements TaRotationService, EntityHandler<TaRotation> {

    private final List<String> errorMessages = new ArrayList<>();
    @Autowired
    private SysOrgService sysOrgService;
    @Autowired
    private SysPositionService sysPositionService;

    @Override
    public TaRotation handleEntity(TaRotation entity, Integer index) throws Exception {
//校验验证
        System.out.println("******************************entity**************************************");
        System.out.println(entity);

        String orgCode = entity.getSpecificOrgNum();//单位机构号
        String orgName = entity.getSpecificOrgName().replaceAll("\n", "");//单位机构名
        String rotationName = entity.getCounterImpPositions().replaceAll("\n", "");//岗位名
        LocalDate durationOfEmployment = entity.getDurationOfEmployment();
        LocalDate rotationExeTime = entity.getRotationExeTime();
        LocalDate rotationDeadline = entity.getRotationDeadline();
        LocalDate planRotationDate = entity.getPlanRotationDate();

        Long count = sysOrgService.countBy("org_id", orgCode, true);
        if (count == 0||orgCode.isEmpty()) {
            errorMessages.add("第 " + index + " 行处理发生错误: " + "没有此机构号 " + orgCode);
        }

        count = sysOrgService.countBy("name", orgName, true);
        if (count == 0||orgName.isEmpty()) {
            errorMessages.add("第 " + index + " 行处理发生错误: " + "没有此机构名字 " + orgName);
        }

        count = sysPositionService.countBy("name", rotationName, true);
        if (count == 0||rotationName.isEmpty()) {
            errorMessages.add("第 " + index + " 行处理发生错误: " + "没有此岗位 " + rotationName);
        }

        if (durationOfEmployment == null) {
            errorMessages.add("第 " + index + " 行时间错误:从事相应重要岗位时间为 " + durationOfEmployment);
        }
        if (rotationExeTime == null) {
            errorMessages.add("第 " + index + " 行时间错误:轮岗截止日期为 " + rotationExeTime);
        }
        if (rotationDeadline == null) {
            errorMessages.add("第 " + index + " 行时间错误:轮岗执行时间 " + rotationDeadline);
        }
        if (planRotationDate == null) {
            errorMessages.add("第 " + index + " 行时间错误:计划轮岗日期 " + planRotationDate);
        }
        return entity;
    }

    //    @Transactional(rollbackFor = Exception.class)
    @Override
    public void saveEntityBatch(List<TaRotation> entityList) {
        // 实现逻辑：保存批量实体
        System.out.println("******************************entityList**************************************");
        System.out.println(entityList);
        for (TaRotation taRotation : entityList) {
            baseMapper.insert(taRotation);
        }
    }


    public List<String> getErrorMessages() {

            return errorMessages;

    }
}

